==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/ending/dialogs_bg.lua <==
dialogId("z-v-doma", "font_big", "I am glad to be home again.")
dialogStr("Радвам съм, че съм отново у дома.")

dialogId("z-m-pocit", "font_small", "I have such a good feeling of the work well done.")
dialogStr("Колко е приятно усещането за добре свършена работа.")

dialogId("z-v-sef", "font_big", "The boss called a moment ago. He was very satisfied with our performance.")
dialogStr("Шефът се обади преди малко. Беше много доволен от нас.")

dialogId("z-m-nemluv", "font_small", "Don’t mention the boss to me. He sits somewhere in his cozy office and we have to do all the dirty work.")
dialogStr("Не ми говори за шефа. Стои си в удобния кабинет, а ние трябва да вършим цялата работа.")

dialogId("z-v-slyset", "font_big", "Shhh, he could hear us.")
dialogStr("Шшшш, може да ни чуе.")

dialogId("z-m-netusi", "font_small", "How could he? He surely doesn’t even know how long it took us.")
dialogStr("Как би могъл? Едва ли знае колко време ни отне задачата.")

dialogId("z-m-dlouho", "font_small", "Really? It didn’t seem that long to me.")
dialogStr("Нима? На мен не ми се видя толкова дълго.")

dialogId("z-v-pozdrav", "font_big", "Dear player. We would like to communicate to you the high regards of the authors of this game. If you didn’t solve it by some cheat, you are really very, very good. It’s a pity we cannot see you from here, but...")
dialogStr("Скъпи играчо, бихме искали да ти предадем високите почитанията на авторите на играта. Ако не си шмекерувал, ти си наистина много, много добър. Жалко, че не можем да те видим оттук, но...")

dialogId("z-m-oblicej", "font_small", "Could you please put your face in front of the hard disk LED? You might not know it but it is a kind of computer’s eye through which...")
dialogStr("Може ли да погледнеш лампичката на твърдия диск отблизо? Сигурно не знаеш, но тя е един вид компютърно око, през което...")

dialogId("z-v-forky", "font_big", "Stop this jokes of yours. This is a very special moment. So:")
dialogStr("Спри с шегите си. Моментът е много специален. Затова:")

dialogId("z-o-blahoprejeme", "font_both", "CONGRATULATIONS!!!")
dialogStr("ПОЗДРАВЛЕНИЯ!!!")

dialogId("z-c-1", "", "")
dialogStr("")

dialogId("z-c-2", "", "")
dialogStr("")

dialogId("z-c-3", "", "")
dialogStr("")

dialogId("z-c-4", "", "")
dialogStr("")

dialogId("z-c-5", "", "")
dialogStr("")

dialogId("z-c-6", "", "")
dialogStr("")

dialogId("z-c-7", "", "")
dialogStr("")

dialogId("z-c-8", "", "")
dialogStr("")

dialogId("z-c-9", "", "")
dialogStr("")

dialogId("z-c-10", "", "")
dialogStr("")

dialogId("z-c-11", "", "")
dialogStr("")

dialogId("z-c-12", "", "")
dialogStr("")

dialogId("z-c-13", "", "")
dialogStr("")

dialogId("z-c-14", "", "")
dialogStr("")

dialogId("z-c-15", "", "")
dialogStr("")

dialogId("z-c-16", "", "")
dialogStr("")

dialogId("z-c-17", "", "")
dialogStr("")

dialogId("z-c-18", "", "")
dialogStr("")

dialogId("z-c-19", "", "")
dialogStr("")

dialogId("z-c-20", "", "")
dialogStr("")

dialogId("z-c-30", "", "")
dialogStr("")

dialogId("z-c-40", "", "")
dialogStr("")

dialogId("z-c-50", "", "")
dialogStr("")

dialogId("z-c-60", "", "")
dialogStr("")

dialogId("z-c-70", "", "")
dialogStr("")

dialogId("z-c-80", "", "")
dialogStr("")

dialogId("z-c-90", "", "")
dialogStr("")

dialogId("z-c-100", "", "")
dialogStr("")

dialogId("z-c-200", "", "")
dialogStr("")

dialogId("z-c-sta", "", "")
dialogStr("")

dialogId("z-c-set", "", "")
dialogStr("")

dialogId("z-c-tisic", "", "")
dialogStr("")

dialogId("z-c-tisice", "", "")
dialogStr("")

dialogId("z-c-hodin", "font_white", "To be specific, it took you %1 hours!")
dialogStr("За да бъдем конкретни, това ти отне %1 часа!")

dialogId("z-c-konkretne", "", "")
dialogStr("")

dialogId("bar-x-suck0", "", "")
dialogStr("")

dialogId("bar-x-suck1", "", "")
dialogStr("")

dialogId("bar-x-suck2", "", "")
dialogStr("")

dialogId("bar-x-suck3", "", "")
dialogStr("")

dialogId("bar-x-suckano", "", "")
dialogStr("")

==> fillets-ng-data_1.0.1.orig.tar.gz: fillets-ng-data-1.0.1/script/ending/dialogs_bg.lua <==
dialogId("z-v-doma", "font_big", "I am glad to be home again.")
dialogStr("Радвам съм, че съм отново у дома.")

dialogId("z-m-pocit", "font_small", "I have such a good feeling of the work well done.")
dialogStr("Колко е приятно усещането за добре свършена работа.")

dialogId("z-v-sef", "font_big", "The boss called a moment ago. He was very satisfied with our performance.")
dialogStr("Шефът се обади преди малко. Беше много доволен от нас.")

dialogId("z-m-nemluv", "font_small", "Don’t mention the boss to me. He sits somewhere in his cozy office and we have to do all the dirty work.")
dialogStr("Не ми говори за шефа. Стои си в удобния кабинет, а ние трябва да вършим цялата работа.")

dialogId("z-v-slyset", "font_big", "Shhh, he could hear us.")
dialogStr("Шшшш, може да ни чуе.")

dialogId("z-m-netusi", "font_small", "How could he? He surely doesn’t even know how long it took us.")
dialogStr("Как би могъл? Едва ли знае колко време ни отне задачата.")

dialogId("z-m-dlouho", "font_small", "Really? It didn’t seem that long to me.")
dialogStr("Нима? На мен не ми се видя толкова дълго.")

dialogId("z-v-pozdrav", "font_big", "Dear player. We would like to communicate to you the high regards of the authors of this game. If you didn’t solve it by some cheat, you are really very, very good. It’s a pity we cannot see you from here, but...")
dialogStr("Скъпи играчо, бихме искали да Ви предадем високите почитанията на авторите на играта. Ако не сте шмекерували, Вие сте наистина много, много добъри. Жалко, че не можем да Ви видим оттук, но...")

dialogId("z-m-oblicej", "font_small", "Could you please put your face in front of the hard disk LED? You might not know it but it is a kind of computer’s eye through which...")
dialogStr("Може ли да погледнете лампичката на твърдия диск отблизо? Сигурно не знаете, но тя е един вид компютърно око, през което...")

dialogId("z-v-forky", "font_big", "Stop this jokes of yours. This is a very special moment. So:")
dialogStr("Спри с шегите си. Моментът е много специален. Затова:")

dialogId("z-o-blahoprejeme", "font_both", "CONGRATULATIONS!!!")
dialogStr("ПОЗДРАВЛЕНИЯ!!!")

dialogId("z-c-1", "", "")
dialogStr("")

dialogId("z-c-2", "", "")
dialogStr("")

dialogId("z-c-3", "", "")
dialogStr("")

dialogId("z-c-4", "", "")
dialogStr("")

dialogId("z-c-5", "", "")
dialogStr("")

dialogId("z-c-6", "", "")
dialogStr("")

dialogId("z-c-7", "", "")
dialogStr("")

dialogId("z-c-8", "", "")
dialogStr("")

dialogId("z-c-9", "", "")
dialogStr("")

dialogId("z-c-10", "", "")
dialogStr("")

dialogId("z-c-11", "", "")
dialogStr("")

dialogId("z-c-12", "", "")
dialogStr("")

dialogId("z-c-13", "", "")
dialogStr("")

dialogId("z-c-14", "", "")
dialogStr("")

dialogId("z-c-15", "", "")
dialogStr("")

dialogId("z-c-16", "", "")
dialogStr("")

dialogId("z-c-17", "", "")
dialogStr("")

dialogId("z-c-18", "", "")
dialogStr("")

dialogId("z-c-19", "", "")
dialogStr("")

dialogId("z-c-20", "", "")
dialogStr("")

dialogId("z-c-30", "", "")
dialogStr("")

dialogId("z-c-40", "", "")
dialogStr("")

dialogId("z-c-50", "", "")
dialogStr("")

dialogId("z-c-60", "", "")
dialogStr("")

dialogId("z-c-70", "", "")
dialogStr("")

dialogId("z-c-80", "", "")
dialogStr("")

dialogId("z-c-90", "", "")
dialogStr("")

dialogId("z-c-100", "", "")
dialogStr("")

dialogId("z-c-200", "", "")
dialogStr("")

dialogId("z-c-sta", "", "")
dialogStr("")

dialogId("z-c-set", "", "")
dialogStr("")

dialogId("z-c-tisic", "", "")
dialogStr("")

dialogId("z-c-tisice", "", "")
dialogStr("")

dialogId("z-c-hodin", "font_white", "To be specific, it took you %1 hours!")
dialogStr("За да бъдем конкретни, това Ви отне %1 часа!")

dialogId("z-c-konkretne", "", "")
dialogStr("")

dialogId("bar-x-suck0", "", "")
dialogStr("")

dialogId("bar-x-suck1", "", "")
dialogStr("")

dialogId("bar-x-suck2", "", "")
dialogStr("")

dialogId("bar-x-suck3", "", "")
dialogStr("")

dialogId("bar-x-suckano", "", "")
dialogStr("")
